# woj
You can interact with WASM OJ Wonderland through this API

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.0.0
- Package version: 0.0.1
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import woj
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import woj
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import woj
from woj.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://woj.csie.cool
# See configuration.py for a list of all supported configuration parameters.
configuration = woj.Configuration(
    host = "https://woj.csie.cool"
)



# Enter a context with an instance of the API client
with woj.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = woj.AuthApi(api_client)
    token = 'token_example' # str | 

    try:
        api_response = api_instance.api_auth_get(token)
        print("The response of AuthApi->api_auth_get:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AuthApi->api_auth_get: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://woj.csie.cool*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AuthApi* | [**api_auth_get**](docs/AuthApi.md#api_auth_get) | **GET** /api/auth | 
*AuthApi* | [**api_auth_send_post**](docs/AuthApi.md#api_auth_send_post) | **POST** /api/auth/send | 
*ProblemApi* | [**api_problem_get**](docs/ProblemApi.md#api_problem_get) | **GET** /api/problem | 
*ProblemApi* | [**api_problem_id_get**](docs/ProblemApi.md#api_problem_id_get) | **GET** /api/problem/{id} | 
*SubmissionApi* | [**api_submission_get**](docs/SubmissionApi.md#api_submission_get) | **GET** /api/submission | 
*SubmissionApi* | [**api_submission_id_get**](docs/SubmissionApi.md#api_submission_id_get) | **GET** /api/submission/{id} | 
*SubmissionApi* | [**api_submission_post**](docs/SubmissionApi.md#api_submission_post) | **POST** /api/submission | 
*DefaultApi* | [**api_me_get**](docs/DefaultApi.md#api_me_get) | **GET** /api/me | 
*DefaultApi* | [**api_sys_get**](docs/DefaultApi.md#api_sys_get) | **GET** /api/sys | 


## Documentation For Models

 - [ApiAuthGet200Response](docs/ApiAuthGet200Response.md)
 - [ApiAuthSendPost200Response](docs/ApiAuthSendPost200Response.md)
 - [ApiAuthSendPost400Response](docs/ApiAuthSendPost400Response.md)
 - [ApiAuthSendPostRequest](docs/ApiAuthSendPostRequest.md)
 - [ApiMeGet200Response](docs/ApiMeGet200Response.md)
 - [ApiProblemGet200Response](docs/ApiProblemGet200Response.md)
 - [ApiProblemGet200ResponseProblemsInner](docs/ApiProblemGet200ResponseProblemsInner.md)
 - [ApiProblemIdGet200Response](docs/ApiProblemIdGet200Response.md)
 - [ApiProblemIdGet200ResponseProblem](docs/ApiProblemIdGet200ResponseProblem.md)
 - [ApiProblemIdGet200ResponseProblemPolicyInner](docs/ApiProblemIdGet200ResponseProblemPolicyInner.md)
 - [ApiProblemIdGet200ResponseProblemTestcaseInner](docs/ApiProblemIdGet200ResponseProblemTestcaseInner.md)
 - [ApiSubmissionGet200Response](docs/ApiSubmissionGet200Response.md)
 - [ApiSubmissionGet200ResponseSubmissionsInner](docs/ApiSubmissionGet200ResponseSubmissionsInner.md)
 - [ApiSubmissionIdGet200Response](docs/ApiSubmissionIdGet200Response.md)
 - [ApiSubmissionIdGet200ResponseSubmission](docs/ApiSubmissionIdGet200ResponseSubmission.md)
 - [ApiSubmissionPost200Response](docs/ApiSubmissionPost200Response.md)
 - [ApiSubmissionPostRequest](docs/ApiSubmissionPostRequest.md)
 - [ApiSysGet200Response](docs/ApiSysGet200Response.md)
 - [ApiSysGet200ResponseCfg](docs/ApiSysGet200ResponseCfg.md)
 - [ApiSysGet200ResponseStat](docs/ApiSysGet200ResponseStat.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="bearerAuth"></a>
### bearerAuth

- **Type**: Bearer authentication (JWT)


## Author

jacob@csie.cool


